==> cypress-cucumber-preprocessor-1.5.0.tgz: package/createTestFromScenario.js <==
/* eslint-disable prefer-template */
const { resolveAndRunStepDefinition } = require("./resolveStepDefinition");

const stepTest = function(stepDetails) {
  cy.log(`${stepDetails.keyword} ${stepDetails.text}`);
  resolveAndRunStepDefinition.call(this, stepDetails);
};

const createTestFromScenario = (scenario, backgroundSection) => {
  if (scenario.examples) {
    scenario.examples.forEach(example => {
      const exampleValues = [];

      example.tableBody.forEach((row, rowIndex) => {
        example.tableHeader.cells.forEach((header, headerIndex) => {
          exampleValues[rowIndex] = Object.assign({}, exampleValues[rowIndex], {
            [header.value]: row.cells[headerIndex].value
          });
        });
      });

      exampleValues.forEach((_, index) => {
        // eslint-disable-next-line prefer-arrow-callback
        it(`${scenario.name} (example #${index + 1})`, function() {
          if (backgroundSection) {
            backgroundSection.steps.forEach(step => {
              stepTest.call(this, step);
            });
          }

          scenario.steps.forEach(step => {
            const newStep = Object.assign({}, step);
            Object.entries(exampleValues[index]).forEach(column => {
              if (newStep.text.includes("<" + column[0] + ">")) {
                newStep.text = newStep.text.replace(
                  "<" + column[0] + ">",
                  column[1]
                );
              }
            });

            stepTest.call(this, newStep);
          });
        });
      });
    });
  } else {
    it(scenario.name, function() {
      if (backgroundSection) {
        backgroundSection.steps.forEach(step => stepTest.call(this, step));
      }
      scenario.steps.forEach(step => stepTest.call(this, step));
    });
  }
};

module.exports = {
  createTestFromScenario
};

==> cypress-cucumber-preprocessor-1.6.0.tgz: package/createTestFromScenario.js <==
/* eslint-disable prefer-template */
const { resolveAndRunStepDefinition } = require("./resolveStepDefinition");

const stepTest = function(stepDetails) {
  cy.log(`${stepDetails.keyword} ${stepDetails.text}`);
  resolveAndRunStepDefinition.call(this, stepDetails);
};

const replaceParameterTags = (rowData, text) =>
  Object.keys(rowData).reduce(
    (value, key) => value.replace(`<${key}>`, rowData[key]),
    text
  );

const createTestFromScenario = (scenario, backgroundSection) => {
  if (scenario.examples) {
    scenario.examples.forEach(example => {
      const exampleValues = [];

      example.tableBody.forEach((row, rowIndex) => {
        example.tableHeader.cells.forEach((header, headerIndex) => {
          exampleValues[rowIndex] = Object.assign({}, exampleValues[rowIndex], {
            [header.value]: row.cells[headerIndex].value
          });
        });
      });

      exampleValues.forEach((rowData, index) => {
        // eslint-disable-next-line prefer-arrow-callback
        const scenarioName = replaceParameterTags(rowData, scenario.name);
        it(`${scenarioName} (example #${index + 1})`, function() {
          if (backgroundSection) {
            backgroundSection.steps.forEach(step => {
              stepTest.call(this, step);
            });
          }

          scenario.steps.forEach(step => {
            const newStep = Object.assign({}, step);
            newStep.text = replaceParameterTags(rowData, newStep.text);

            stepTest.call(this, newStep);
          });
        });
      });
    });
  } else {
    it(scenario.name, function() {
      if (backgroundSection) {
        backgroundSection.steps.forEach(step => stepTest.call(this, step));
      }
      scenario.steps.forEach(step => stepTest.call(this, step));
    });
  }
};

module.exports = {
  createTestFromScenario
};
